## SCALING UP OF CROP PRODUCTION PROCESSORS IN ALMERIA##

setwd("C:/R_Almeria_p/Data") ##windows users

## SCALING FROM CROPS TO FARMS 

# Data load and wrangling
crop_proc<-read.csv('Input/crop_proc.csv', header=TRUE, sep=';',dec = ".")
relations<-read.csv('Input/relations.csv', header=TRUE, sep=';',dec = ",")

proc_l3<-crop_proc[,c("processor.uuid","variable.class","value_int")]
library(tidyr)
proc_l3<-spread(proc_l3, variable.class, value_int, fill=0) 
rel_l32<-relations[relations$categorization=="crop",c("processor.uuid","parent.uuid", "dependency.value")]
nv<-names(proc_l3[2:length(proc_l3)])

# Upscaling 
upscaling3<-merge(rel_l32, proc_l3, by.x=c("processor.uuid"),
                     by.y=c("processor.uuid")) #Link tables

upCrop<-as.data.frame(matrix(data=NA, nrow=nrow(upscaling3), ncol=ncol(upscaling3)-2)) #Watch dim!!
upCrop[,1]<-upscaling3[,2] #Select column with uuid for level 2- Farms, watch colnums
colnames(upCrop)<-c("processor.uuid",nv)

for (j in 1:nrow(upCrop)) {
      for (i in 2:ncol(upCrop)) {  #watch colnums
        upCrop[j,i]<-upscaling3[j,"dependency.value"]*upscaling3[j,i+2] 
    }
}

farm_cropup<-rowsum(upCrop[,2:ncol(upCrop)],upCrop$processor.uuid, reorder=TRUE) #summing values by farm
library(data.table)
setDT(farm_cropup, keep.rownames = TRUE)[] #Transforming matrix into table, doesnt work in all R versions
colnames(farm_cropup)[1]<-c("processor.uuid") 

# New interfaces in farm processors (intensive values)
#Calculated
FERT<-(farm_cropup$K+farm_cropup$P+farm_cropup$N)*2.5 #Fertilizers=SUM(nutrients_req)*Parameter for calibration
farm_cropup<-within(farm_cropup, rm("K","N","P","LU")) #Remove nutrients and LU because it is the scaling factor
farm_cropup<-cbind(farm_cropup,FERT)

# From other data sources
farm_proc<-read.csv('Input/farm_proc.csv', header=TRUE, sep=';',dec = ",") #new intensive variables for farming systems
proc_l2<-farm_proc[,c("processor.uuid","variable.class","value_int")] #Watch col_names

library(tidyr)
proc_l2<-spread(proc_l2, variable.class,value_int, fill=0)
proc_l2<-within(proc_l2, rm("LU"))

farm_proc_int<-as.data.frame(merge(farm_cropup, proc_l2,by.x=c("processor.uuid"),
                  by.y=c("processor.uuid"))) #Ouptut - Farm processor variables description by intensive values per ha

# Transforming to extensive
farm_proc_ext<-as.data.frame(matrix(data=NA, nrow=nrow(farm_proc_int), ncol=ncol(farm_proc_int)+1)) #dataframe for extensive values of interfaces
farm_proc_ext[,1]<-farm_proc_int[,1]
farm_proc_ext[,ncol(farm_proc_ext)]<-farm_proc[farm_proc$variable.class=="LU","value_ext"] #subsetting scaling factor land use

for (j in 1:nrow(farm_proc_ext)) {
  for (i in 2:(ncol(farm_proc_ext)-1)) {
    farm_proc_ext[j,i]<- farm_proc_int[j,i]*farm_proc_ext[j,ncol(farm_proc_ext)] #watch extensive units (ton, thousand m3 for water)
  } 
}
colnames(farm_proc_ext)<-c(names(farm_proc_int),"LU") #Ouptut - Farm intefaces description by extensive values

# EXPORT OUTPUTS
write.csv(farm_proc_ext, file = "Output/farm_proc_ext.csv")
write.csv(farm_proc_int, file = "Output/farm_proc_int.csv")


## SCALING  UP FROM FARMs TO IRRIGATION AREAS 

# Data load and wrangling
ias_proc<-read.csv('Input/ias_proc.csv', header=TRUE, sep=';',dec = ".") ##Linux
rel_21<-relations[relations$categorization=="farm",c("processor.uuid","parent.uuid", "dependency.value")]

# Upscaling intensive values 
upscaling2<-merge(rel_21, farm_proc_int,by.x=c("processor.uuid"),
                  by.y=c("processor.uuid")) #Link tables

upFarm<-as.data.frame(matrix(data=NA, nrow=nrow(upscaling2), ncol=ncol(farm_proc_int)))
upFarm[,1]<-upscaling2[,2] #watch colnums
colnames(upFarm)<-names(farm_proc_int)

for (j in 1:nrow(upFarm)) {
  for (i in 2:ncol(upFarm)) {  #watch colnums
    upFarm[j,i]<-upscaling2[j,"dependency.value"]*upscaling2[j,i+2] #watch colnums
  }
}

ia_farmup<-rowsum(upFarm[,2:ncol(upFarm)],upFarm$processor.uuid, reorder=TRUE) #summing values by irrigation area
library(data.table) 
ia_proc_int<-setDT(ia_farmup, keep.rownames = TRUE)[] #transforming matrix into table
colnames(ia_proc_int)[1]<-c("processor.uuid") 

#Tranforming to extensive
ia_proc_int<-as.data.frame(ia_proc_int) #need to transform to dataframe to calculate loops!
ia_proc_ext<-as.data.frame(matrix(data=NA, nrow=nrow(ia_proc_int), ncol=ncol(ia_proc_int)+1))
ia_proc_ext[,1]<-ia_proc_int[,1]
ia_proc_ext[,ncol(ia_proc_ext)]<-ias_proc[ias_proc$variable.class=="LU","value_ext"] #scaling factor Land use

for (j in 1:nrow(ia_proc_ext)) {
  for (i in 2:(ncol(ia_proc_ext)-1)) {
    ia_proc_ext[j,i]<-ia_proc_int[j,i]*ia_proc_ext[j,ncol(ia_proc_ext)]/1000 #WATCH UNITS!
  } 
}
colnames(ia_proc_ext)<-c(names(ia_proc_int),"LU") #Ouptut - Irrigation areas intefaces description by extensive values, 

# EXPORT OUTPUTS
write.csv(ia_proc_ext, file = "Output/ia_proc_ext.csv")
write.csv(ia_proc_int, file = "Output/ia_proc_int.csv")
